/* $Id: stricmp.c,v 1.5 2001/04/18 00:11:26 richdawe Exp $ */

/*
 *  stricmp.c - Case insensitive string comparisons
 *  Copyright (C) 1999-2001 by Richard Dawe
 *      
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "common.h"

#if !defined(HAVE_STRICMP) || !defined(HAVE_STRNICMP)

#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#include "strlwr.h"
#include "stricmp.h"

/* ------------
 * - strnicmp -
 * ------------ */

/* Linux, BSD have strncasecmp(), so use that if possible. */
#ifdef HAVE_STRNCASECMP

int __inline__
strnicmp (const char *string, const char *string2, size_t n)
{
  return(strncasecmp(string, string2, n));
}
#else /* !HAVE_STRNCASECMP */

int
strnicmp (const char *string, const char *string2, size_t n)
{
  char *r = NULL, *s = NULL;
  int ret = 0;

  if ((string == NULL) || (string2 == NULL)) return(0);

  r = strdup(string);
  s = strdup(string2);
  strlwr(r);
  strlwr(s);
  ret = strncmp(r, s, n);
  free(s);
  free(r);
  return(ret);
}

#endif /* HAVE_STRNCASECMP */

/* -----------
 * - stricmp -
 * ----------- */

/* Linux, BSD have strcasecmp(), so use that if possible. */
#ifdef HAVE_STRCASECMP

int __inline__
stricmp (const char *string, const char *string2)
{
  return(strcasecmp(string, string2));
}

#else /* !HAVE_STRCASECMP */

int stricmp (const char *string, const char *string2)
{
  char *r = NULL, *s = NULL;
  int ret = 0;

  if ((string == NULL) || (string2 == NULL)) return(0);

  r = strdup(string);
  s = strdup(string2);
  strlwr(r);
  strlwr(s);
  ret = strcmp(r, s);
  free(s);
  free(r);
  return(ret);
}

#endif /* HAVE_STRCASECMP */

#endif /* !HAVE_STRICMP || !HAVE_STRNICMP */
